@@ -9,7 +9,7 @@ import traceback
 import click
 from tabulate import tabulate
 
-from ._core import (
+from .core import (
     CreateTableMigration,
     Database,
     DatabaseMigrator,
@@ -191,12 +191,13 @@ def main_drop_column(db_path, table, column):
 
 @cli.command(name="drop-table")
 @click.option("--db", "db_path")
+@click.option("--schema", "schema_path")
 @click.argument("table")
-def main_drop_table(db_path, table):
+def main_drop_table(db_path, schema_path, table):
     """
     Drop a table from the database.
     """
-    with Database(db_path) as db:
+    with Database() as db:
         count = db.count(table)
         print(f"WARNING: Table {table!r} contains {count} row(s) of data.")
         print()
@@ -205,7 +206,9 @@ def main_drop_table(db_path, table):
             print("Operation aborted.")
             sys.exit(1)
 
-        db.drop_table(table)
+    schema_module = get_schema_module(schema_path)
+    with DatabaseMigrator(schema_module=schema_module) as migrator:
+        migrator.drop_table(table)
         print()
         print(f"Table {table!r} dropped from the database.")
 
@@ -374,10 +377,14 @@ def base_list(
     default=False,
     help="Run the database in debug mode.",
 )
-def main_migrate(db_path, schema_path, table, *, write, no_backup, debug):
+def main_migrate_wrapper(*args, **kwargs):
     """
     Migrate the database to match the Python schema.
     """
+    main_migrate(*args, **kwargs)
+
+
+def main_migrate(db_path, schema_path, table, *, write, no_backup, debug):
     schema_module = get_schema_module(schema_path)
     with DatabaseMigrator(
         db_path, schema_module=schema_module, readonly=not write, debugger=debug
@@ -388,8 +395,10 @@ def main_migrate(db_path, schema_path, table, *, write, no_backup, debug):
             return
 
         if write and not no_backup:
-            _, backup_name = tempfile.mkstemp(prefix="kgdb-backup-", suffix=".sqlite3")
-            shutil.copy2("/home/iafisher/me.sqlite3", backup_name)
+            _, backup_name = tempfile.mkstemp(
+                prefix="isqlite-backup-", suffix=".sqlite3"
+            )
+            shutil.copy2(db_path, backup_name)
 
         tables_created = 0
         tables_dropped = 0
